@@ -123,6 +123,12 @@ class RejawClient(object):
     def unmute_conversation(self, conversation_id):
         return self._post('conversation/unmute', {'cid': conversation_id})
         
+    def favorite_conversation(self, conversation_id):
+        return self._post('conversation/favorite', {'cid': conversation_id})
+        
+    def unfavorite_conversation(self, conversation_id):
+        return self._post('conversation/favorite', {'cid': conversation_id})
+        
     def subscribe(self, topic):
         """Subscribe to the given topic(s)"""
         return self._post('subscription/subscribe', {'topic': topic})
